# ETools

ETools is an open-source python package that allows you to many things with ease, using command prompt.


## Authors

- [**Wyatt Johnson**](https://github.com/realendie)


## Features

- Ability to download any YouTube video free of charge.
- Ability to convert file types with ease.


## Roadmap

- Add the ability to just download audio from video.

- Add the option to use a GUI instead of CMD or Terminal.


## Installation

To install ETools run the command:

```

```


    